@@ -1130,7 +1130,7 @@ class MQLInterface(BaseInterface):  # noqa: D
         query_result = self.execute(query, variable_values={"queryId": query_id, "cursor": cursor})["mqlQuery"]
         tabular = query_result["resultTabular"]
         df = pd.read_json(
-            base64.b64decode(tabular["data"].encode()),
+            base64.b64decode(tabular["data"].encode()).decode(),
             orient="table",
         )
         return QueryResult(
@@ -1186,6 +1186,6 @@ class MQLInterface(BaseInterface):  # noqa: D
         while cursor is not None:
             query_result = self.get_query_page_as_df(query_id, cursor)
             cursor = query_result.cursor
-            df = df.append(query_result.df, ignore_index=True)
+            df = pd.concat([df, query_result.df], ignore_index=True)
 
         return df
